@@ -267,9 +267,11 @@ class Artifacts:
             else:
                 upload_type = "ARTI_FILES"
 
+            file_index = next((file_index for (file_index, d) in enumerate(entry_dict.keys()) if d == entry.path), None)
             succeeded = entry.upload(upload_type, root_path, self.run.run_id, self.id, last_file_yn, self.run.team_name,
                                      self.run.exp_name, self.run.run_name, self.name, self.type, artifact_digest,
-                                     entry_list, file_index=i)
+                                     entry_list, file_index=file_index)
+
             if not succeeded:
                 return False
         return True
